@@ -1,7 +1,7 @@
 package Bencher::Scenario::TextTableModules;
 
-our $DATE = '2015-10-11'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -89,6 +89,13 @@ our $scenario = {
                 Text::Table::Tiny::table(rows=>$table, header_row=>1);
             },
         },
+        {
+            module => 'Text::Table::Org',
+            code => sub {
+                my ($table) = @_;
+                Text::Table::Org::table(rows=>$table, header_row=>1);
+            },
+        },
         {
             module => 'Text::TabularDisplay',
             code => sub {
@@ -125,12 +132,30 @@ Bencher::Scenario::TextTableModules - Benchmark Perl text table modules
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenario::TextTableModules (from Perl distribution Bencher-Scenario-TextTableModules), released on 2015-10-11.
+This document describes version 0.02 of Bencher::Scenario::TextTableModules (from Perl distribution Bencher-Scenario-TextTableModules), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
  % bencher -m TextTableModules [other options]...
 
+=head1 BENCHMARKED MODULES
+
+L<Text::ANSITable>
+
+L<Text::ASCIITable>
+
+L<Text::FormatTable>
+
+L<Text::MarkdownTable>
+
+L<Text::Table>
+
+L<Text::Table::Tiny>
+
+L<Text::Table::Org>
+
+L<Text::TabularDisplay>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenario-TextTableModules>.
